Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(37)

Unified Diff: chrome/browser/sync/glue/data_type_manager_mock.cc

Issue 10832286: sync: Introduce control data types (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Rebase Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/sync/glue/data_type_manager_mock.cc
diff --git a/chrome/browser/sync/glue/data_type_manager_mock.cc b/chrome/browser/sync/glue/data_type_manager_mock.cc
index 9c420b059725e1cb42ceafd9c3d2f24adc3ebda3..bd5f8d82fe2cfe24dfee5520c52d22346edf4ebd 100644
--- a/chrome/browser/sync/glue/data_type_manager_mock.cc
+++ b/chrome/browser/sync/glue/data_type_manager_mock.cc
@@ -23,10 +23,9 @@ DataTypeManagerMock::DataTypeManagerMock()
this, static_cast<int>(chrome::NOTIFICATION_SYNC_CONFIGURE_DONE),
&result_)));
- // By default, calling ConfigureWithoutNigori will send a SYNC_CONFIGURE_START
- // and SYNC_CONFIGURE_DONE notification with a DataTypeManager::OK
- // detail.
- ON_CALL(*this, ConfigureWithoutNigori(testing::_, testing::_)).
+ // By default, calling Purge will send a SYNC_CONFIGURE_START and
+ // SYNC_CONFIGURE_DONE notification with a DataTypeManager::OK detail.
+ ON_CALL(*this, Purge(testing::_, testing::_)).
WillByDefault(testing::DoAll(
NotifyFromDataTypeManager(
this,

Powered by Google App Engine
This is Rietveld 408576698